function x = SRdecode(Y,output_length,FMT)
%SR_decode This is the decoder of the stack run run-length encoder.
%
%   INPUT: Y is an array of integers contain 3,2,1,0 or strings 
%           contain '+,-,1,0'.
%          FMT is the string indicating format of input. 'char' or 'double'
%          are allowed. 'double' is default format.
%          output_length is the desired output length.
%
%   OUTPUT: x is an array of integers.
%
%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% by A. Kim
% date created: 02.10.2011
% last change: 02.10.2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
x = [];

if nargin == 0
    fprintf('ERROR: no input given');
elseif nargin ==1 || nargin == 2|| strcmp(FMT,'double')==1 
    y = Y;
elseif strcmp(FMT, 'char')==1
    % converting string into to double. 
    y(Y=='+') = 3;
    y(Y=='-') = 2;
    y(Y=='1') = 1;
    y(Y=='0') = 0;
else
    fprintf('ERROR: unknown input format.');
    y = [];
end
    



while ~isempty(y)
    if length(y)>1
        % find the '+','-', '1' and '0' positions 
        PM_pos = find(y==3| y==2);
        OZ_pos = find(y==1|y==0);
        
        % y always starts with the symbol '+' or '-'
        
        if isempty(OZ_pos) % only runs of zeros.
            temp3 = y(1:length(y));
            y = [];
            temp3(temp3==3)=1;
            
            temp3(temp3==2)=0;
            
            numbr = bit2int([1 temp3]);
            
            % check if the length is 2^k-1
            
            if round(log2((numbr)+1))-log2((numbr)+1)==0
                rl = bit2int(temp3);
                rl_zeros = zeros(1,rl);
            else
                rl_zeros = zeros(1,numbr);
            end
            
                    
                x = [x rl_zeros];

        elseif isempty(PM_pos) % only 1 or zeros. (not valid code word) 
            x = y;
            y = [];
        elseif ~isempty(OZ_pos) && OZ_pos(1)==2 % first codeword is none-zero value
        
            % check the sign of the none-zero value.
            if y(PM_pos(1))==3
               nz_sign = 1;
            elseif y(PM_pos(1))==2
                nz_sign = -1;
            end
               
               
            %convert the binary into decimal.
            % remove the codeword from y
         
            if length(PM_pos)>1
                temp = [1 y(2:PM_pos(2)-1)];
                y = y(PM_pos(2):length(y));
                
            else% no other valide codeword in the input.
                temp = [1 y(2:length(y))];
                y = [];
            end
            
         
            x = [x nz_sign*(bit2int(temp)-1)];
            
        elseif OZ_pos(1) ==1 %first codword is 1/0. decode as 1/0.
                x = [x y(1)];
                
                % remove codeword.
                y = y(2:length(y));
                
        elseif OZ_pos(1)>2% first code word is run length of zeros.
                        %if ~isempty(OZ_pos)
                temp3 = y(1:OZ_pos(1)-2);% remember the nz val has MSB.
                y = y(OZ_pos(1)-1:length(y));
                
                temp3(temp3==3)=1;
                
                temp3(temp3==2)=0;
                
                numbr = bit2int([1 temp3]);
                
                
                if round(log2((numbr)+1))-log2((numbr)+1)==0 % if the length is 2^k-1
                    rl = bit2int(temp3); % then all bits are there
                    rl_zeros = zeros(1,rl); 
                else % if not, need the one with added bits.
                    rl_zeros = zeros(1,numbr);
                end
                
                    
                x = [x rl_zeros];
        end
       
    elseif length(y)==1 
        if y == 3 || y == 0% here y = +, then only 1 zero is left.
            x = [x 0];
        elseif y == 2 % here y = -, two zeros are left.
            x = [x 0 0];
        elseif y == 1 
            x = [x 1];
   
        end
            y = [];
    end
end
                
            
%check to see if x is at the right length.
if nargin >=2
    if output_length > length(x)
        x = [x zeros(1,output_length-length(x))];
    else
        x = x(1:output_length);
    end
end         
