function [corr_coeffs power] = autocorrcoeffs_3D(M)
    %input: 3D array, zero-mean
    %output: - vector corr_coeffs with correlation coefficients
    %          (along 1st, 2nd and 3rd dimension)
    %        - estimated power (variance) of M
    
    N_tot = length(M(:)); %total number of samples
    shifts = [1 0 0]; %indicating which dimension to shift
    r = zeros(1,3); %initiating covariance vector
    for i = 1:3
        N_r = prod(size(M)-shifts); %total number of samples in estimation
        r(i) = sum(sum(sum(M(1:end-shifts(1),1:end-shifts(2),1:end-shifts(3))...
        .*M(shifts(1)+1:end,shifts(2)+1:end,shifts(3)+1:end))))/N_r; 
        shifts = circshift(shifts,[0 1]);
    end
    power = sum(sum(sum(M.^2)))/N_tot;
    corr_coeffs = r/power;
end