function f_rec = dpcm3D_decode(e_q,pred_coeffs,q_param,MC_shift)
    imsize = size(e_q);
    f_rec = zeros(imsize);
    
    q_param_nopred = q_param{1};
    q_param2D = q_param{2};
    q_param3D = q_param{3};
    
    a2D = pred_coeffs{1};
    a3D = pred_coeffs{2};
    
    x_mc = MC_shift; %Assume shift in the x-direction common to all frames
    
    % Coordinates for 3D prediction window:
    m = [1 0 -x_mc]; % image x-direction
    n = [0 1 0]; % image y-direction
    p = [0 0 1]; % time direction
    % Coordinates for 2D prediction window:
    m2D = [1 0 1]; % image x-direction
    n2D = [0 1 1]; % image y-direction 
    
    for t = 1: imsize(3) % For each frame
         for y = 1: imsize(1) % For each row
             f_p = 0;    %predicted value
             for x = 1 : imsize(2) % For each pixel
                if ((~(y <= 1 || x < 1 || x == imsize(2)) && (t <= 1))... %due to prediction window
                   || (~(y <= 1 || x == imsize(2)) && x >= (imsize(2)-x_mc))) %due to motion compensation
                     pred_mode = '2D';
                elseif (~(y <= 1 || x < 1 || x == imsize(2)) && (t > 1))
                     pred_mode = '3D';
                else
                    pred_mode = 'none';
                end
                
                %--Reconstruction
                    if(strcmp(pred_mode, 'none')) 
                        e_q_rec(y,x,t) = inv_uniform_quantizer(e_q(y,x,t), q_param_nopred);                        
                    elseif(strcmp(pred_mode, '2D'))
                        e_q_rec(y,x,t) = inv_deadzone_quantizer(e_q(y,x,t), q_param2D);
                    elseif(strcmp(pred_mode, '3D'))
                        e_q_rec(y,x,t) = inv_deadzone_quantizer(e_q(y,x,t), q_param3D);
                    end
                % e_q_rec(y,x,t) = e_q(y,x,t); %testing without Q
                f_rec(y,x,t)  = e_q_rec(y,x,t)  + f_p; 

                %--Prediction---
                %Update prediction signal (for next sample) 
                f_p_temp = 0;
                if(strcmp(pred_mode, '2D'))
                    %2D prediction for the first frame:
                    for l = 1:length(a2D)
                        f_p_temp = f_p_temp+a2D(l)*f_rec(y-n2D(l),x-m2D(l)+1,t); %indexes relative to current px!
                    end
                elseif(strcmp(pred_mode, '3D'))
                    %3D prediction for the rest:
                    for k = 1:length(a3D)
                        %f(y,x+1,t) %testing
                        %f(y,x+1,t-1)%testing
                        f_p_temp = f_p_temp+a3D(k)*f_rec(y-n(k),x-m(k)+1,t-p(k));%%indexes relative to current px!
                    end
                end

                f_p = f_p_temp; 
             end
         end
    end
end
        
