function e_q = dpcm3D_encode(f, pred_coeffs, q_param, MC_shift)
    %DPCM encoder with 3D predictor, order decided by prediction window W
    %Input signal: f (3D matrix), input image sequence (video), must have zero mean!
    %Output signals: e_q (3D matrix), quantized prediction error
    %                a (double vector), prediction coefficients
    
    if(~iscell(q_param))
        quantize = 0;
    else 
        quantize = 1;
        q_param_nopred = q_param{1};
        q_param2D = q_param{2};
        q_param3D = q_param{3};
    end
    
    a2D = pred_coeffs{1};
    a3D = pred_coeffs{2};
    
    x_mc = MC_shift; %Assume shift in the x-direction common to all frames

    f_size=size(f);
    f_rec = zeros(f_size); %internal reconstructed signal
    % Coordinates for 3D prediction window:
%without MC    
%     m = [1 0 0]; % image x-direction
%     n = [0 1 0]; % image y-direction
%     p = [0 0 1]; % time direction
%     % Coordinates for 2D prediction window:
%     m2D = [1 0 1]; % image x-direction
%     n2D = [0 1 1]; % image y-direction    
    m = [1 0 -x_mc]; % image x-direction
    n = [0 1 0]; % image y-direction
    p = [0 0 1]; % time direction
    % Coordinates for 2D prediction window:
    m2D = [1 0 1]; % image x-direction
    n2D = [0 1 1]; % image y-direction  

    %Encoding:
    for t = 1: f_size(3) % For each frame
         for y = 1: f_size(1) % For each row
                f_p = 0;    %predicted value
                for x = 1 : f_size(2) % For each pixel
                        if ((~(y <= 1 || x < 1 || x == f_size(2)) && (t <= 1))... %due to prediction window
                            || (~(y <= 1 || x == f_size(2)) && x >= (f_size(2)-x_mc))) %due to motion compensation
                            pred_mode = '2D';
                        elseif (~(y <= 1 || x < 1 || x == f_size(2)) && (t > 1))
                            pred_mode = '3D';
                        else
                            pred_mode = 'none';
                        end
                    %Difference signals
                    e = f(y,x,t)-f_p;     %prediction error
                    
                    %--Quantization and inverse quantization:
                    if(quantize == 0) %quantization turned off
                        e_q(y,x,t) = e;
                        e_q_rec(y,x,t) = e;
                    elseif(strcmp(pred_mode, 'none'))
                        e_q(y,x,t) = uniform_quantizer(e,q_param_nopred);
                        e_q_rec(y,x,t) = inv_uniform_quantizer(e_q(y,x,t), q_param_nopred);                        
                    elseif(strcmp(pred_mode, '2D'))
                        e_q(y,x,t) = deadzone_quantizer(e,q_param2D);
                        e_q_rec(y,x,t) = inv_deadzone_quantizer(e_q(y,x,t), q_param2D);
                    elseif(strcmp(pred_mode, '3D'))
                        e_q(y,x,t) = deadzone_quantizer(e,q_param3D);
                        e_q_rec(y,x,t) = inv_deadzone_quantizer(e_q(y,x,t), q_param3D);
                    end

                    %--Reconstruction (internal decoding)
                    f_rec(y,x,t)  = e_q_rec(y,x,t) + f_p; 
                    
                    %--Prediction---
                    %Update prediction signal (for next sample) 
                    f_p_temp = 0;
                    if(strcmp(pred_mode, '2D'))
                        %2D prediction for the first frame:
                        for l = 1:length(a2D)
                            f_p_temp = f_p_temp+a2D(l)*f_rec(y-n2D(l),x-m2D(l)+1,t); %indexes relative to current px!
                        end
                    elseif(strcmp(pred_mode, '3D'))
                        %3D prediction for the rest:
                        for k = 1:length(a3D)
                            f_p_temp = f_p_temp+a3D(k)*f_rec(y-n(k),x-m(k)+1,t-p(k));%%indexes relative to current px!
                        end
                    end
                    
                    f_p = f_p_temp;           
                end
         end
    end



