% DPCM parameter testing script
 clear
 close all

%--- Prepare parameters and inputs ---
 
%Define images:
make_test_images_dpcm %make test images sequence without motion compensation 
%frame_shift = [0 3];
%make_test_images_dpcm_mc %make test image sequence with motion compensation 

im_mat = video_mat;
nr_px = numel(video_mat);
nr_px_frame = size(video_mat,1)^2;
nr_frames = size(video_mat,3);
nr_rows = size(video_mat,1);
%MC_shift = round(frame_shift(2));
MC_shift = 0;
%Prediction windows:
W3D = [1 0 0; 0 1 0; 0 0 1]; 
W2D = [1 0; 0 1; 1 1];
%Subtract mean:
im_mat_mean = mean(mean(im_mat));
for i = 1:size(im_mat,3)
    im_mat0(:,:,i) = im_mat(:,:,i)-im_mat_mean(1,1,i);
end
%Compute prediction coefficients
pred_coeffs = cell(1,2);
[a2D power2D] = est_2Dpredcoeffs(im_mat0(:,:,1), W2D,'debug');
[a3D power3D] = est_3Dpredcoeffs(im_mat0, W3D,'debug');
pred_coeffs{1} = a2D;
pred_coeffs{2} = a3D;


%---Estimation of Quantization parameters-----

L1 = 11;
L2 = 7;
L3 = 7;
dz_l = 1.25;
q_param = set_q_param(L1,L2,L3, dz_l,im_mat0,pred_coeffs, MC_shift,'debug');

%-----DPCM Encode---------
e_q3D = dpcm3D_encode(double(im_mat0), pred_coeffs, q_param,MC_shift);
%SR-encoding
e_q3D_coded = sr3D_encode(e_q3D);
rate = length(e_q3D_coded)/length(e_q3D(:))

%-----Decode---------
e_q3D_decoded = e_q3D; %no SR-coding
%-SR-decoding:
%e_q3D_decoded = sr3D_decode(e_q3D_coded,nr_rows, nr_frames);

f_rec3D = dpcm3D_decode(e_q3D_decoded,pred_coeffs,q_param,MC_shift);
for i = 1:size(im_mat,3)
    f_rec3D(:,:,i) = f_rec3D(:,:,i)+im_mat_mean(1,1,i);
end
im_mat_rec3D = uint8(f_rec3D);


%Recovered sequence vs. original sequence
%step_im_sequence(im_mat_rec3D)
figure
imshow(im_mat_rec3D(:,:,2));
title('recovered image, with mean')
figure
imshow(uint8(im_mat(:,:,2)));
title('Original image, with mean')

%--Histograms:
e_q3D0 = [e_q3D(1:end,1,1)' e_q3D(1, 1:end, 1)];
e_q3D1 = e_q3D(2:end,2:end,1);
e_q3D2 = e_q3D(2:end,2:end,2);
figure
subplot(3,1,1)
hist(e_q3D0(:),max(e_q3D0(:))-min(e_q3D0(:)))
title('Edges without prediction')
%title('Histogram of quantizer output, not predicted pixels 1st frame')
subplot(3,1,2)
hist(e_q3D1(:),max(e_q3D1(:))-min(e_q3D1(:)))
title('2D prediction')
%title('Histogram of quantizer output, 2D predicted pixels 1st frame')
subplot(3,1,3)
hist(e_q3D2(:)+0.5,max(e_q3D2(:))-min(e_q3D2(:)))
title('3D prediction')
%title('Histogram of quantizer output, 3D predicted frames')


%-- Compute entropy and SNR:
%e_q3D = e_q3D(2:end, 2:end, 2:end);
bins = max(e_q3D(:))-min(e_q3D(:));
histogram = hist(e_q3D(:),bins);
prob = histogram./sum(histogram); %probability distribution
figure
entropy = 0;
for m=1:bins
     if prob(m) > 0
        entropy = entropy - prob(m)*log2(prob(m));
     end
end
entropy

diff_sig = uint8(im_mat(2:end,2:end,2:end))-im_mat_rec3D(2:end,2:end,2:end);
PSNR=20*log10(255/std(double(diff_sig(:))))



