function q_param = set_q_param(L1,L2,L3, dz_loading,f,pred_coeffs,MC_shift,debug)

    if(nargin < 3)
        debug = 0;
    else
        debug = 1;
    end
    
    loading = 5;
    
    %encoding without quantization:
    e_q = dpcm3D_encode(double(f),pred_coeffs,0,MC_shift);

    %Grouping pixels in prediction categories:
    % Group 1: without prediction
    e_q1 = [e_q(1:end,1,1)' e_q(1, 1:end, 1)]; 
    % Group 2: 2D predicted
    e_q2 = e_q(2:end,2:end,1);
    % Group 3: 3D predicted
    e_q3 = e_q(2:end,2:end,2:end); 

    %Compute standard deviation of different prediction categories:
    std_eq1 = std(e_q1(:)); %better to estimate from the whole image?
    std_eq2 = std(e_q2(:));
    std_eq3 = std(e_q3(:));

    %Compute quantization parameters:
    range1 = std_eq1; %compute differently?
    
    range2 = std_eq2*loading;
    range3 = std_eq3*loading;
    
    dz_offset2 = 2*std_eq2*dz_loading;
    dz_offset3 = 2*std_eq3*dz_loading;
    
    q_param = cell(1,3);
    q_param{1} = struct('L', L1, 'range', range1);
    q_param{2} = struct('L', L2, 'range', range2, 'dz_offset', dz_offset2);
    q_param{3} = struct('L', L3, 'range', range3, 'dz_offset', dz_offset3);
    

    if(debug ==1)
        disp('Quantizer 1')
        std_eq1
        figure
        subplot(3,1,1)
        disp(q_param{1})
        plotQ(q_param{1}, 'Quantizer 1')
        
        disp('Quantizer 2')
        std_eq2
        subplot(3,1,2)
        disp(q_param{2})
        plotQ(q_param{2},'Quantizer 2' )
        
        disp('Quantizer 3')
        std_eq3
        subplot(3,1,3)
        disp(q_param{3})
        plotQ(q_param{3},'Quantizer 3')
        
        %Plotting histogram of different frame outputs:
%         figure
%         hist(e_q1(:),max(e_q1(:))-min(e_q1(:)))
%         title('Histogram of quantizer output frame 1, edges without prediction')
%         figure
%         hist(e_q2(:),max(e_q2(:))-min(e_q2(:)))
%         title('Histogram of quantizer output frame 1, 2D prediction')
%         figure
%         hist(e_q3(:),max(e_q3(:))-min(e_q3(:)))
%         title('Histogram of quantizer for 3D predicted frames')
        figure
        subplot(3,1,1)
        hist(e_q1(:),max(e_q1(:))-min(e_q1(:)))
        title('Edges without prediction')
        axis([-15 15 0 30])
        subplot(3,1,2)
        hist(e_q2(:),max(e_q2(:))-min(e_q2(:)))
        title('2D prediction')
        axis([-15 15 0 3000])
        subplot(3,1,3)
        hist(e_q3(:),max(e_q3(:))-min(e_q3(:)))
        title('3D prediction')
        axis([-15 15 0 15000])
    end  
end