function q_level = uniform_quantizer(x,q_param)
    %% --Quantization with uniform deadzone quantizer
    % input: x - input signal (one sample)
    %        dz_offset - (two-sided) width of dead-zone interval
    %        range - one-sided range
    %        L - number of quantization levels
    % output: quantization level for sample x
    %% -------
    L = q_param.L;
    range = q_param.range;
    
    % Compute step size outside deadzone
    step_size = 2*range/L;
    % Compute maximum quantization level
    %max_q_level = (dz_offset+step_size*(L-1)-step_size*0.5)/2;
    max_q_level = range-0.5*step_size;
    %clip input outside the quantizer range:
    x_clipped = min(abs(x),max_q_level);
    
    %map to one-sided uniform midtread with step_size=1
    x_mapped = max(0,(x_clipped./step_size));
    % add sign back:
    x_signed = sign(x).*x_mapped;
    
    % shift signal to get all-positive values:
    x_pos = x_signed+L+1;
    % round to nearest integer and add sign:
    q_level_pos = round(x_pos);
    % shift signal back 
    q_level = q_level_pos-(L+1);
end