% This is a script used to gain knowledge about the duration of the passes

%clear all
close all

% SIMULATION INPUT GOES HERE (AND IN STK)
altitudes = [350 500 650];      % different orbital altitudes
thresholds = [21 28 34];        % different threshold elevation angles
%thresholds = [0 0 0];          % to simulate TOTAL visibity

                                % one angle for each altitude.
schemes = strvcat('r','g','b'); % Different plot colors (and dots etc.)

% Loads the data. If the variable already exist, the program will assume it
% is from the previous run, and save time by not loading it again. The
% "clear all" command at the top of the script must be commented for that.
if(~exist('data'))
    for i=1:length(altitudes)
        data{i}= read_stk_elev([num2str(altitudes(i)) 'c.txt']);
        disp(['Datafile for altitude ' num2str(altitudes(i)) ' km loaded.']);
    end
else
    disp(['Data already loaded. If not true; run "clear data".']);
end

for ind=1:length(altitudes)

    intervals = threshold_stk_elev(data{ind},thresholds(ind));

    if(isempty(intervals))  % Elevation never passes threshold
        start=0;
        stop=0;
    else
        start = datenum(intervals(:,1:6));
        stop = datenum(intervals(:,7:12));    
    end

    duration_d = stop-start;        % This is the duration of the passes in days.
    duration_h = duration_d*24;     % ... and in hours
    duration_m = duration_h*60;     % ... and in minutes.
    duration_s = duration_m*60;     % ... and in seconds.

    N = size(intervals,1); % The number of passes during the
                           % simulation time (1 week)

    % Length on the passes (in ascending order) are store to outside the
    % loop in this variable for all altitudes.
    dur{ind} = sort(duration_m);
                           
    disp(['Simulation for altitude ' num2str(altitudes(ind)) ' km finished.']);
    
end

% Creating legends
legs = [];
for alt=1:length(altitudes)
    legs = strvcat(legs,[num2str(altitudes(alt)) ' km']);
end

for ind=1:length(altitudes)
    altstr = num2str(altitudes(ind));
    durt = dur{ind};
    mindur = num2str(min(durt));
    maxdur = num2str(max(durt));
    meddur = num2str(median(durt));
    meandur = num2str(mean(durt));
    disp(['Pass duration information for ' altstr ' km altitude:']);
    disp(['  Minimum duration: ' mindur ' min.']);
    disp(['  Maximum duration: ' maxdur ' min.']);
    disp(['  Mean duration:    ' meandur ' min.']);
    disp(['  Median duration:  ' meddur ' min.']);
    
    figure
    hist(durt,5);
    title(['Distribution of duration for ' altstr ' km altitude']);
    xlabel('Duration [min]');
    ylabel('Number of passes');
end