% This is a script that plots the downloaded data per average day for
% different orbital heights and threshold elevation angles.

%clear all
close all

% SIMULATION INPUT GOES HERE (AND IN STK)
altitudes = [350 500 650];      % different orbital altitudes
thresholds = 0:90;            % different threshold elevation angles
zoom = 15:40;                   % Make a plot for these angles only
schemes = strvcat('r','g','b'); % Different plot colors (and dots etc.)

% D and I is hold the average kB downloaded during an average day and an
% average pass, respectively, for various altitudes and thresholds.
D = zeros(length(altitudes),length(thresholds));
I = D;

% Loads the data. If the variable already exist, the program will assume it
% is from the previous run, and save time by not loading it again. The
% "clear all" command at the top of the script must be commented for that.
if(~exist('data'))
    for i=1:length(altitudes)
        data{i}= read_stk_elev([num2str(altitudes(i)) 'c.txt']);
        disp(['Datafile for altitude ' num2str(altitudes(i)) ' km loaded.']);
    end
else
    disp(['Data already loaded. If not true; run "clear data".']);
end

for alt=1:length(altitudes)
    
    for thr=1:length(thresholds)
        
        intervals = threshold_stk_elev(data{alt},thresholds(thr));
        
        if(isempty(intervals))  % Elevation never passes threshold
            start=0;
            stop=0;
        else
            start = datenum(intervals(:,1:6));
            stop = datenum(intervals(:,7:12));    
        end
        
        duration_d = stop-start;        % This is the duration of the passes in days.
        duration_h = duration_d*24;     % ... and in hours
        duration_m = duration_h*60;     % ... and in minutes.
        duration_s = duration_m*60;     % ... and in seconds.
        
        T = sum(duration_s);   % Total duration of pass in seconds
        N = size(intervals,1); % The number of passes during the
                               % simulation time (1 week)
        
        R = 9600;       % Assuming bitrate of 9600 bps
        W = R*T;        % Bits downloaded during simulation time (1 week)
%       W = (W/8)/1024; % W is now kB per week.
        W = W/(1024^2); % W is no Mb (megabit) per week.
        D(alt,thr) = W/7; % D is Mb per average day.
        I(alt,thr) = W/N; % I is Mb download per average pass.
        
    end
    
    disp(['Simulation for altitude ' num2str(altitudes(alt)) ' km finished.']);
    
end

% Creating legends
legs = [];
for alt=1:length(altitudes)
    legs = strvcat(legs,[num2str(altitudes(alt)) ' km']);
end

% Plot Data per Day
figure
hold on
grid on
for alt=1:length(altitudes)
    plot(thresholds,D(alt,:),schemes(alt,:));
end
xlabel('Minimum Elevation Angle [degree]');
ylabel('Average Downlink Capacity [Mb/day]');
% title('Average Data per Day for Different Criterea');
legend(legs);

% Plot Data per Day (with zoom)
first = find(thresholds==zoom(1));
last = find(thresholds==zoom(end));

figure
hold on
grid on
for alt=1:length(altitudes)
    plot(thresholds(first:last),D(alt,first:last),schemes(alt,:));
end
xlabel('Minimum Elevation Angle [degree]');
ylabel('Average Downlink Capacity [Mb/day]');
% title('Average Data per Day for Different Criterea');
legend(legs);
% a = [18,24,30];
% b = [D(1,19) D(2,25) D(3,31)];
a = [21,28,34];
b = [D(1,22) D(2,29) D(3,35)];
plot(a,b,'ok');

% Plot Data per Pass
figure
hold on
grid on
for alt=1:length(altitudes)
    plot(thresholds,I(alt,:),schemes(alt,:));
end
xlabel('Minimum Elevation Angle [degree]');
ylabel('Average Downlink Capacity [Mb/pass]');
% title('Average Data per (Usable) Pass for Different Criteria');
legend(legs);