function satcam_param = compute_and_set_satcam_param(column_number)
% column_number: picks the column (i.e. set of parameters) in sat_param.txt

% Import variables and constants from text files (column number chooses which column in sat_param to use
import_vars('sat_param.txt', column_number);
import_vars('sat_const.txt',1);


% Compute variables regarding satellite and camera:
T = 2*pi*sqrt((earth_radius+height_sat)^3/g_param); % Satellite orbital period
speed_sat_OH = 2*pi*(earth_radius*1000+height_OH*1000)/T; % satellite speed w.r.t OH layer
image_cov = (2*((height_sat-height_OH)*1000)*tan((FOV*pi/180)/2)); % Image coverage
image_cov_wl = image_cov/(gw_min_wl*1000); % Image coverage in wavelengths
spat_res = image_cov/array_size; % coverage per pixel [m]
image_speed = speed_sat_OH/spat_res; %satelite speed in pixels per second

% Defining the output struct:
satcam_param = struct('T',T,'speed_sat_OH',speed_sat_OH, 'image_cov', image_cov,...
                'image_cov_wl',image_cov_wl,'spat_res', spat_res,...
                'image_speed', image_speed, 'height_sat', height_sat, 'FOV', FOV, ...
                'array_size', array_size, 'reset_time', reset_time);

end