%% -----Image averaging-------
% Script for simulation of image averaging with motion compensation
%----------------------------
close all
%% Choose and load videos and parameters
clear all
%video_sim %Run video sim the first time to generate test videos and parameters
param_set_name = 'report_set_testing'; % Choose parameter set
load(['parameters_' param_set_name], 'all_param') % Load parameters
load(['videos_' param_set_name], 'videos') % Load videos

% Show the first image of each video as a thumbnail:
thumbnails = show_video_thumbnails(videos);
% Display parameters:
display_struct_rows_rec(all_param)
%% -------------------

%% Simple demo:
index = 3; % Choose which video(s) in the video set to work with
video_duration = 5; 
im_comb_stack = cell(1,index);
video_param = all_param(index).video_param;
frames_to_combine = video_duration*video_param.frame_rate;
% Combine frames:
[im_comb im_comb_cropped] = video_frame_comb(videos{index},video_param,frames_to_combine); 
% Plot first frame and averaged image:
im_comb_stack = cell(1,2);
im_comb_stack{1} = thumbnails{index};
im_comb_stack{2} = im_comb_cropped;
plot_im_stack(im_comb_stack,'w', {'First frame', 'Averaged image'})

%% Varying video durations:
index = 2; % Choose which video(s) in the video set to work with
video_duration = [2 5];
im_comb_stack = cell(1,index);
video_param = all_param(index).video_param;
%Combine frames:
im_comb_stack{1} = thumbnails{index};
im_comb_stack_eq{1} = histeq(thumbnails{index},256);
for j = 1: length(video_duration)
    frames_to_combine = video_duration(j)*video_param.frame_rate;
    [im_comb im_comb_cropped] = video_frame_comb(videos{index},video_param,frames_to_combine); 
    im_comb_stack{j+1} = im_comb_cropped;
end
plot_im_stack(im_comb_stack,'w')


%% Testing frame combining with incorrect frame shift values:
index = 3; % Choose which video in the video set to work with
video_param = all_param(index).video_param;
video_duration = 5;
frames_to_combine = video_param.frame_rate*video_duration;
% Make vector with wrong frame_shifts:
frame_shift = video_param.frame_shift;
error_vector = [0.9 1 0.9]';
frame_shift_fake =zeros(length(error_vector),2);
frame_shift_fake(:,1) = zeros(length(error_vector),1);
frame_shift_fake(:,2) = frame_shift(2)*error_vector.*ones(length(error_vector),1);
errors = frame_shift_fake(:,2)-(frame_shift(2).*ones(length(error_vector),1));
%im_comb_fake = cell(1,length(error_vector));
im_stack = cell(1,length(error_vector));
titles = cell(1,length(error_vector));
for i = 1:length(error_vector)
    video_param.frame_shift = frame_shift_fake(i,:);
    titles{i} = num2str(error_vector(i));
    [im_comb_fake im_comb_fake_cropped] = video_frame_comb(videos{index},video_param,frames_to_combine);
    im_stack{i} = im_comb_fake_cropped;
end
% Plot resulting combined images:
plot_im_stack(im_stack,'q', titles);

