%% -----Video simulation script--------
% Script for simulation of video generation
% Computes and defines sets of different parameters for video generation and stores
% them in the structs satcam_param, video_param and image_param.
% Series of videos are then generated by videomaker2, with the parameter sets chosen in parameters. T

% To show any of the finished videos (number 1 in this example):
% implay(uint8(videos{1}),0.25*video_param(1).frame_rate)
%% -----------------------------
close all
clear all

%% Define possible frame rate and video duration:
frame_rate = [5 10];
video_time = 5; %setting number of frames as a constant times frame rate
frames = video_time.*frame_rate;

%% Read parameters from files and generate video parameters
%(Generate video parameters for different combinations of satelite
%parameters and frame rates)
i=1;
k=1;
while(i ~= 0) % runs as long as import_vars manages to read a new column from sat_param.txt
    try
        % Importing and computing satellite and camera parameters and constants:
        satcam_param(i) = compute_and_set_satcam_param(i);
        % Computing and setting video parameters:
        for j = 1:length(frame_rate)
            video_param(k) = compute_and_set_video_param(satcam_param(i),frame_rate(j),frames(j));
            k=k+1;
        end
        i=i+1;
    catch me
        i=0;
        %rethrow(me) %for debugging of the things inside try
    end
end

% Display the video parameters:
display_struct_rows_rec(video_param)

%% Define parameters for sine image used for video generation:
%(syntax: dc level, SNR_factor, angle)
image_param(1) = compute_and_set_image_param(0.6, 0, 10);
image_param(2) = compute_and_set_image_param(0.6, 5, 10);
image_param(3) = compute_and_set_image_param(0.6, 20, 10);
image_param(4) = compute_and_set_image_param(0.6, 50, 10);
image_param(5) = compute_and_set_image_param(0.6, 100, 10);

%% Define parameter set combinations for video making:
%(Choose combinations of video parameters and image parameters 
% Syntax: [video_param image_param], possible to generate several sets)

name = 'report_set_testing';
parameter_sets = [... %new syntax: video_param image_param
    3 1
    3 2
    3 3
    3 4
    3 5];

%% Making high resolution images and low resolution video:
for j = 1:size(parameter_sets,1)
    %Setting current image and video parameters
    v_index = parameter_sets(j,1);
    im_index = parameter_sets(j,2);
    % Make high resolution image and corresponding video with current parameters:
    highres_images{j} = make_sine_image_for_video(video_param(v_index), image_param(im_index));
    videos{j} = video_maker(highres_images{j},video_param(v_index),image_param(im_index));
    % Display all the parameters:
    disp(['----------Parameters video ' num2str(j) '---------------'])
    disp(video_param(v_index))
    disp('     --------------------')
    disp(video_param(v_index).satcam_param)
    disp('     --------------------')
    disp(image_param(im_index))
    % Collect all the parameters:
    all_param(j) = struct('video_param', video_param(v_index),...
                    'image_param', image_param(im_index));
end
%% Save videos and corresponding parameters for use in test scripts:
save(['videos_' name], 'videos')
save(['parameters_' name], 'all_param')







