function [im_blurred_mat h_mb] = motionblur_maker(im, blur_len, blur_angle)
    %Simulation of motion blur, returning a matrix with blurred images and
    %blur kernels
    %(former name: mb_sim)
   
    if(nargin<4)
        blur_angle=0;
    end

    cut_length = ceil(max(blur_len)/3); %Defining how much to cut according to blur length
    
   
    %im_blurred_mat = zeros(size(im,1)-2*cut_length, size(im,2)-2*cut_length, length(blur_len)+1);
    im_blurred_mat = cell(length(blur_len)+1);
    
    % Cutting, plotting and saving the original image:
    im_cut = im((cut_length+1):(end-cut_length),(cut_length+1):(end-cut_length)); %Cut to compare with blurred image
    im_blurred_mat{1} = im_cut;
    h_mb{1}=0;
    %{
    figure
    subplot(ceil(length(blur_len)/3),3,1)
    imshow(im_cut)
    title(im_name);
    %}
    
    % Generating and plotting blurred images:

    for i = 1:length(blur_len)
        % Create blur
        h_mb{i+1} = fspecial('motion', blur_len(i), blur_angle);
        temp = imfilter(im,h_mb{i+1},'conv','replicate');
        
        % Cut edges to avoid artifacts:
        im_blurred_mat{i+1} = temp((cut_length+1):(end-cut_length),(cut_length+1):(end-cut_length));
        
        % Plot
        %{
        subplot(ceil(length(blur_len)/3),3,i+1)
        imshow(uint8(im_blurred_mat(:,:,i+1)))
        title(['blur length=' num2str(floor(blur_len(i)))]);
        %}
    end
end

