%% Simulation of detector background and noise

clear all
close all
% numbers for dark offset and fpn from experiment (1s 20deg):
dark_offset = 1123;
std_fpn = 248;
std_dn = 5.54;

im_size = [256 256];
%% 1D

fpn = std_fpn*randn(1,256);
dn = std_dn*randn(1,256);
snr_scale = 2;

%signal
x = 1:256;
num_of_periods = 15;
sine_period = length(x)/num_of_periods;
sine_offset = snr_scale*dark_offset;
sine_amp = 0.05*sine_offset;
sig_sine = sine_offset+sine_amp*sin(2*pi*1/sine_period*x);

% add photon noise:
% std_photon = sqrt(sine_offset);
% photon_noise = std_photon.*randn(1,256);
% sig_noise1 = sig_sine + photon_noise;
% figure
% stem(x,photon_noise)

yrange = 4000;

figure
subplot(1,3,1)
plot(x,sig_sine)
ylabel('Counts')
axis([1 256 0 yrange])

% figure
% plot(x,sig_noise1)
% axis([1 256 0 2*sine_offset])

sig_noise2 = sig_sine + dark_offset + fpn + dn;
sig_dark = dark_offset+fpn+dn;
% figure
% plot(x,sig_dark)
% axis([1 256 0 2*sine_offset])

sig_noise3 = sig_noise2-fpn-dark_offset;

subplot(1,3,2)
plot(x,sig_noise2)
ylabel('Counts')
axis([1 256 0 yrange])
subplot(1,3,3)
plot(x,sig_noise3)
ylabel('Counts')
axis([1 256 0 yrange])

%% 2D:
%Making image with sine signal and background

common_scale = 0.8; %must be scaled down for high background levels

%sine parameters:
number_of_periods = 11.5;
sine_dc = 0.6; % DC level of sine images
sine_dc = sine_dc*common_scale;
sine_angle = 30;
sine_amp = 0.05*sine_dc;
std_phn = sqrt(sine_dc);

snr_scale = 1; %ratio between sine dc level and background level
bg_scale = sine_dc/(snr_scale*dark_offset);

%making image noise:
fpn = std_fpn*randn(im_size); %background fixed pattern noise
dn = std_dn*randn(im_size); %background dark (thermal) noise
%phn = std_phn*randn(im_size); %photon noise

bg = zeros(im_size)+dark_offset+fpn+dn; %background signal
%bg_normalized = bg./max(bg(:)); %normalizing to one;
bg_normalized = common_scale*bg_scale.*bg;
dn_normalized = common_scale*bg_scale.*dn;
im_bg = uint8(256*bg_normalized); %making an 8-bit image
im_dn = uint8(256*dn_normalized);

im_sig = make_sinus_image(im_size(1), number_of_periods, sine_dc, sine_amp,sine_angle);
%im_sig_noisy = im_sig+(uint8(256*phn)); %tried to make photon noise, get the wrong scaling

im_total = im_sig+im_bg;
im_dn_sig = im_sig+im_dn;

figure
imshow(im_bg)
%save_figure(gcf,['bg_k' num2str(snr_scale)])
figure
imshow(im_sig)
%save_figure(gcf,['sig_k2'num2str(snr_scale)])
figure
imshow(im_total)
%save_figure(gcf,['total_k'num2str(snr_scale)])
figure
imshow(im_dn_sig)   

